Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EnvironmentLister ¶
type EnvironmentLister interface {
// List lists all Environments in the indexer.
List(selector labels.Selector) (ret []*v1.Environment, err error)
// Environments returns an object that can list and get Environments.
Environments(namespace string) EnvironmentNamespaceLister
EnvironmentListerExpansion
}
EnvironmentLister helps list Environments.
func NewEnvironmentLister ¶
func NewEnvironmentLister(indexer cache.Indexer) EnvironmentLister
NewEnvironmentLister returns a new EnvironmentLister.
type EnvironmentListerExpansion ¶
type EnvironmentListerExpansion interface{}
EnvironmentListerExpansion allows custom methods to be added to EnvironmentLister.
type EnvironmentNamespaceLister ¶
type EnvironmentNamespaceLister interface {
// List lists all Environments in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.Environment, err error)
// Get retrieves the Environment from the indexer for a given namespace and name.
Get(name string) (*v1.Environment, error)
EnvironmentNamespaceListerExpansion
}
EnvironmentNamespaceLister helps list and get Environments.
type EnvironmentNamespaceListerExpansion ¶
type EnvironmentNamespaceListerExpansion interface{}
EnvironmentNamespaceListerExpansion allows custom methods to be added to EnvironmentNamespaceLister.
Click to show internal directories.
Click to hide internal directories.